@@ -2,7 +2,7 @@ import time
 import json
 from typing import Union
 
-from redis import StrictRedis, ConnectionPool
+from redis import StrictRedis
 
 from config import settings
 
@@ -15,7 +15,6 @@ class DbRedisHelper(object):
 
     def __init__(self) -> None:
         self.connection = StrictRedis(
-            connection_pool=ConnectionPool(
                 host=settings.redis_host,
                 port=settings.redis_port,
                 db=settings.redis_lock_db,
@@ -23,7 +22,6 @@ class DbRedisHelper(object):
                 password=settings.redis_password,
                 decode_responses=True,
                 ssl=True
-            )
         )
         self.prefix = 'lock'
 
